/**
 * 表格控件
 */
var IBizCalendar = IBizControl.extend({
	construct: function(config) {
		var me = this;
		arguments.callee.$.construct.call(this,config);
		me.calendar = $('#'+config.id);
		var clickNum = 0;
		var timeIndex = null;
		
		var calendarType = 'listWeek,agendaWeek,month';
		var defaultOpen = 'month';
		
		if(config.calendarStyle == 'WEEK') {
			calendarType = 'agendaWeek';
			defaultOpen = 'agendaWeek';
		} else if(config.calendarStyle == 'MONTH') {
			calendarType = 'month';
			defaultOpen = 'month';
		} else if(config.calendarStyle == 'DAY') {
			calendarType = 'listWeek';
			defaultOpen = 'listWeek';
		}
		if(config.defaultOpen) {
			defaultOpen = config.defaultOpen;
		}

		var option = {
			header: {
				left: 'prev,next today',
				center: 'title',
				right: calendarType
			},
			eventLimit: true,
			eventLimitClick: 'popover',
			handleWindowResize: true,
			height: config.height,
			aspectRatio: 2.5,
			editable: true,
			defaultView: defaultOpen, //默认打开
			events: function(start, end, timezone, callback) {
				var params = {srfaction: 'fetch', srfbegintime: '2018-09-01', srfendtime: '2018-09-30'};
				me.fireEvent(IBizCalendar.BEFORELOAD, me, params);
				me.loadingTags = IBiz.beginload();
				IBiz.ajax({
					url: me.config.url,
					params: params,
					method: 'POST',
					dataType: 'json',
					success: function(data) {
						IBiz.endload(me.loadingTags);
						if(data.ret == 0) {
							$.each(data.items, function(index, item){
								item.start = item.begintime;
								item.end = item.endtime;
								item.title = item.text;
								item.textColor = item.color;
								item.color = item.bkcolor;
							});
							callback(data.items);
							me.fireEvent(IBizCalendar.LOADED, me, data);
						}
					},
					error: function(data) {
						IBiz.endload(me.loadingTags);
					}
				});
			},
			eventClick: function (calEvent, jsEvent, view) {
				if(clickNum == 0) {
					clickNum++;
					timeIndex = window.setTimeout(function(){
						clickNum = 0;
//						me.fireEvent(IBizCalendar.SELECTIONCHANGE, jsEvent, calEvent);
					}, 200);
				} else {
					clickNum = 0;
					window.clearTimeout(timeIndex);
					me.fireEvent(IBizCalendar.ROWDBLCLICK, jsEvent, calEvent);
				}
			},
			eventDrop: function (event, delta, revertFunc, jsEvent, ui, view) {
				var params = {srfaction: 'update',srfitemid: event.id, begintime: event.start.format('YYYY-MM-DD HH:mm:ss'), endtime: event.end.format('YYYY-MM-DD HH:mm:ss')};
				me.fireEvent(IBizCalendar.BEFOREUPDATE, me, params);
				IBiz.ajax({
					url: me.config.url,
					params: params,
					method: 'POST',
					dataType: 'json',
					success: function(data) {
						if(data.ret == 0) {
							$.extend(event, data);
							me.fireEvent(IBizCalendar.AFTERUPDATE, me, params);
						} else {
							revertFunc();
						}
					},
					error: function(data) {
						
					}
				});
			},
			dayClick: function(date, allDay, jsEvent, view) {
				if(clickNum == 0) {
					clickNum++;
					timeIndex = window.setTimeout(function(){
						clickNum = 0;
					}, 200);
				} else {
					clickNum = 0;
					window.clearTimeout(timeIndex);
					me.fireEvent(IBizCalendar.CLICKDAY, jsEvent, {begintime: date.format('YYYY-MM-DD HH:mm:ss')});
				}
			},
			eventRender: function(event, element) {
				element.append('<i class="fa fa-times event-delete" data="'+event.id+'"></i>');
			}
		};
		me.calendar.fullCalendar(option);
		me.calendar.on("click", ".event-delete", function(e){
			me.fireEvent(IBizCalendar.DELETEEVENT, e, {id: $(this).attr("data")});
		})
		
	},
	gotoDate:function(time){
		var me = this;
		if(!time) {
			return;
		}
		me.calendar.fullCalendar('gotoDate', time);
	},
	/**
	 * 删除
	 */
	remove: function(arg) {
		var me = this;
		if (!arg) return;
		$.extend(arg, {
			srfaction: 'remove'
		});
		if (IBizApp_Data) {
			arg.srfappdata = IBizApp_Data;
		}
		me.fireEvent(IBizCalendar.BEFOREREMOVE, me, arg);
		IBiz.ajax({
			url: me.config.url,
			params: arg,
			method: 'POST',
			dataType: 'json',
			success: function(data) {
				if (data.ret == 0) {
					me.refresh();
					me.fireEvent(IBizCalendar.REMOVED,me,data);
					if (data.info && data.info != '') {
						IBiz.alert($IGM('IBIZDATAGRID.REMOVE.INFO','删除成功'));
					}
					IBiz.processResult(data);
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.REMOVE.TITLE','删除失败'),$IGM('IBIZDATAGRID.REMOVE.INFO2','删除数据失败,'+ data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	},
	/**
	 * 加载
	 */
	load:function(){
		var me = this;
		me.refresh();
	},
	refresh:function(){
		var me = this;
		me.calendar.fullCalendar('refetchEvents');
	},
	/**
	 * 获取数据仓库<该方法仅在Ext版本中有效>
	 * @Deprecated
	 */
	getStore:function(){
		return null;
	},
	/**
	 * 设置选中数据
	 * @param selections 
	 */
	setSelection:function(selections){
		
	},
	/**
	 * 获取选中数据
	 */
	getSelection:function(){
		if(this.grid){
			return this.grid.bootstrapTable('getSelections');
		}
		return null;
	},
	doUIAction: function(params) {
		var me = this;
		
		if (!params) params = {};
		$.extend(params,{srfaction: 'uiaction'});
		if (IBizApp_Data) {
			params.srfappdata = IBizApp_Data;
		}
		IBiz.ajax({url:me.config.url,
			params:params,
			method:'POST',
			dataType:'json',
			success:function(data){
				if(data.ret == 0){
					if(data.reloadData){
						me.refresh();
					}
					if (data.info && data.info != '') {
						IBiz.alert($IGM('IBIZDATAGRID.DOUIACTION.INFO','操作成功'));
					}
					IBiz.processResult(data);
				}else{
					IBiz.alert($IGM('IBIZDATAGRID.DOUIACTION.TITLE','操作失败'),$IGM('IBIZDATAGRID.DOUIACTION.INFO2','操作失败,执行操作发生错误,'+ data.info,[data.info]),2);
				}
			},
			failure:function(e){
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}	
		});
	},
	/**
	 * 提交工作流操作
	 */
	wfsubmit: function(params) {
		var me = this;
		if (!params) params = {};
		$.extend(params, {
			srfaction: 'wfsubmit'
		});
		if (IBizApp_Data) {
			params.srfappdata = IBizApp_Data;
		}
		IBiz.ajax({
			url: me.config.url,
			params: params,
			method: 'POST',
			dataType: 'json',
			success: function(data) {
				if (data.ret == 0) {
					me.refresh();
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.WFSUBMIT.TITLE','执行失败'),$IGM('IBIZDATAGRID.WFSUBMIT.INFO','执行工作流操作失败,'+ data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	},
	/**
	 * 批量添加
	 */
	addBatch: function(arg) {
		var me = this;
		if (!arg) arg = {};
		$.extend(arg, {srfaction: 'addbatch'});
		
		if (IBizApp_Data) {
			arg.srfappdata = IBizApp_Data;
		}
		IBiz.ajax({
			url: me.config.url,
			params: arg,
			method: 'POST',
			dataType: 'json',
			success: function(data) {
				if (data.ret == 0) {
					me.refresh();
					me.fireEvent(IBizDataGrid.ADDBATCHED, me, data);
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.ADDBATCH.TITLE','添加失败'),$IGM('IBIZDATAGRID.ADDBATCH.INFO','执行批量添加失败,'+ data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	}
		
});
IBizCalendar.ROWDBLCLICK = 'ROWDBLCLICK';  // 双击事件
IBizCalendar.SELECTIONCHANGE = 'SELECTIONCHANGE';  // 选中事件
IBizCalendar.CLICKDAY = 'CLICKDAY';  // 点击日历
IBizCalendar.DELETEEVENT = 'DELETEEVENT';  // 删除事件抛出事件
IBizCalendar.BEFOREREMOVE = 'BEFOREREMOVE';  // 删除数据之前
IBizCalendar.REMOVED = 'REMOVED'; // 删除数据以后
IBizCalendar.BEFORELOAD = 'BEFORELOAD';  // 加载数据以前
IBizCalendar.LOADED = 'LOADED';  // 加载数据以后
IBizCalendar.BEFOREUPDATE = 'BEFOREUPDATE';  // 更新数据之前
IBizCalendar.AFTERUPDATE = 'AFTERUPDATE';  // 更新数据以后