/**
 * 卡片表格控件
 */
var IBizDataGridImg = IBizControl.extend({
	construct: function(config) {
		var me = this;
		arguments.callee.$.construct.call(this,config);
		me.grid = $('#'+config.id);
		me.dataContent = me.grid.find(".grid-img-inner");
		me.pageContent = me.grid.find(".grid-img-bottom");
		me.tableselection = null;
		me.tableselections = {};
		me.selectState = "<input type='checkbox' class='checkBoxClass'/>";
		me.allSelectState = "<div class='allSelect'><input type='checkbox' class='multiSelect'/><span>全选</span></div>";
		//是否分页，默认分页
		me.enablePaging = true; 
		if(config.enablePaging != undefined){
			me.enablePaging = config.enablePaging;
		}
		//设置每页条数
		me.pageSize = 10; 
		if(config.pageSize && config.pageSize > 0){
			me.pageSize = config.pageSize;
		}
		//是否多选 ，默认多选
		me.multiSelect = true; 
		if(config.multiSelect != undefined && config.multiSelect == false){
			me.multiSelect = config.multiSelect;
		}
		//当前默认显示页为第一页
		me.curPage = 1;
		me.totalRecords = 0;
		//表格设置宽高
		me.setSize(me.getWidth(),me.getHeight());
		//单击选中事件
		me.dataContent.on('click', '.grid-img-inner-cont', function(){
			if(me.multiSelect){
				return ;
			}else {
				me.onSelection(this);
			}
		});
		//双击打开事件
		me.dataContent.on('dblclick', '.grid-img-inner-cont', function(){
			var rowIndex = $(this).attr('row-index');
			me.fireEvent(IBizDataGrid.ROWDBLCLICK,event, me.allData[rowIndex]);
		});
		//复选框选中事件
		me.dataContent.on('change',".checkBoxClass", function() { 
			me.onSelection($(this).parent(),this.checked);
		}); 
		//全选框事件
		me.pageContent.on('change','.multiSelect', function(){
			me.allSelection(this.checked);
		});
	},
	getAllData: function(){
		var me = this;
		return me.allData;
	},
	load:function(){
		var me = this;
		me.loadData();
	},
	refresh:function(){
		var me = this;
		me.loadData();
	},
	//获取数据仓库<该方法仅在Ext版本中有效>
	getStore:function(){
		return null;
	},
	//设置表格宽高
	setSize: function(width,height) {
		var me = this;
		me.layoutHeight = height;
		me.layoutWidth = width;
		if(me.grid){
			me.grid.css({"width":width,"height":height});
		}
	},
	//设置表格宽度
	getWidth: function(){
		var me = this;
		if(me.config.width && me.config.width >0){
			return me.config.width;
		}
		return "100%";
	},
	//设置表格高度
	getHeight: function(){
		var me = this;
		if(me.layoutHeight && me.layoutHeight > 0){
			return me.layoutHeight;
		}
		if(me.config.height && me.config.height >0){
			return me.config.height;
		}
		if(me.grid.parent().height() >0){
			return me.grid.parent().height()-2;
		}
		if(me.grid.height() >0){
			return me.grid.height();
		}
		return 400;
	},
	loadData: function(){
		var me = this;
		var params = me.getParams();
    	me.loadingTag = IBiz.beginload();
		IBiz.ajax({
			url: me.config.url,
			params: params,
			method: 'POST',
			dataType: 'json',
			success: function(data){
				IBiz.endload(me.loadingTag);
				if(data.success && data.items){
					me.tableselections = {};
					me.tableselection = null;
					me.allData = data.items;
					if(data.items.length==0 && me.curPage>1){
						me.curPage = me.curPage-1;
						me.loadData();
						return;
					}
					//填充数据内容
					me.innerContent(data.items);
					//加载表格分页工具栏
					me.setPaging(data);
					//抛出事件
					me.fireEvent(IBizDataGrid2.LOADED,me,data.items);
				}else{
					IBiz.alert($IGM('IBIZDATAGRID.GETDATA.TITLE','加载错误信息'),$IGM('IBIZDATAGRID.GETDATA.INFO','加载数据发生错误,'+data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.endload(me.loadingTag);
			}
		});
	},
	//获取请求参数
	getParams: function() {
		var me = this;
		var params = {srfaction:'fetch',srfrender:'JQUERYDATATABLES'};
		//设置搜索参数
		me.fireEvent(IBizDataGrid2.BEFORELOAD,me,params);
    	if(me.config.srfaction){
    		params.srfaction = me.config.srfaction;
    	}
    	//设置每页显示条数
    	if(me.curPage && me.pageSize){
    		params.start=(me.curPage-1)*me.pageSize;
			if(params.start > me.totalRecords)
				params.start=0;
			params.limit=me.pageSize;
			params.length=me.pageSize;
		}
    	return params;
	},
	//数据填充
	innerContent: function(datas) {
		var me = this;
		//清除上次请求展示的数据信息
		me.dataContent.empty();
		var flag = true;
		for(var i = 0;i<datas.length;i++){
			var html = "";
			if(flag){
				var bl = true;
				for(var j=0;j<me.config.columns.length;j++){
					if(me.config.columns[j].render && typeof me.config.columns[j].render == "function"){
						html += me.config.columns[j].render(datas[i][me.config.columns[j].data],'',datas[i]);
						bl = false;
					}
				}
				if(bl) {
					flag = false
				}
			}
			if(!flag) {
				html += "<div>"+datas[i].srfmajortext+"</div>";
			}
			if(me.multiSelect){//复选，则添加复选框
				html += me.selectState;
			}
			me.dataContent.append("<div class='grid-img-inner-cont' row-index='"+i+"'>"+html+"</div>");
		}
	},
	//设置分页工具栏相关参数
	setPaging: function(data) {
		var me = this;
		//统计数据总数
		if(data.totalrow || data.totalrow==0) {
			me.totalRecords = data.totalrow;
		}
		var startrow=data.startrow;
		var limit = data.limit;
		me.curPage = startrow/limit+1;
		me.innerPaging();
	},
	//设置分页工具栏
	innerPaging: function() {
		var me = this;
		//清空分页栏重新加载
		me.pageContent.empty();
		me.pageContent.append("<div id='grid-img-page' class='grid-img-paging'></div>");
		var options = {total: me.totalRecords,numberPage: me.pageSize,curPage: me.curPage};
		$("#grid-img-page").paging(options,function(msg){//回调
			me.curPage = msg;
			me.loadData();
		});
		if(me.multiSelect){
			me.pageContent.append(me.allSelectState);
		}
	},
	//设置选中数据状态
	onSelection: function(e,state){
		var me = this;
		if(me.multiSelect){
			if(state){
				$(e).addClass('shadow');
			}else{
				$(e).removeClass('shadow');
			}
		}else{
			me.dataContent.find('.grid-img-inner-cont').removeClass('shadow');
			$(e).addClass('shadow');
		}
		me.setSelection();
	},
	//全选数据设置
	allSelection: function(state){
		var me = this;
		if(state){
			me.dataContent.find('.grid-img-inner-cont').addClass('shadow');
			me.dataContent.find('.checkBoxClass').prop('checked',true);
		}else{
			me.dataContent.find('.grid-img-inner-cont').removeClass('shadow');
			me.dataContent.find('.checkBoxClass').prop('checked',false);
		}
		me.setSelection();
	},
	//设置选中数据的值
	setSelection : function(){
		var me = this;
		var data = [];
		me.tableselections = {};
		me.tableselection = null;
		//获取选中的数据
		var selects = me.dataContent.find('.grid-img-inner-cont.shadow');
		for (var i = 0, len = selects.length; i < len; i++) {
            var rowIndex = $(selects[i]).attr('row-index');
            var rowData = me.allData[rowIndex];
            data.push(rowData);
            me.tableselections[rowData.srfkey] = rowData;
			me.tableselection = rowData;
        }
		me.fireEvent(IBizDataGrid.SELECTIONCHANGE,me,data);
	},
	//获取选中数据
	getSelection:function(){
		var me = this;
		if(me.tableselections){
			var data = [];
			$.each(me.tableselections,function(key,value){
				data.push(value);
			});
			
			return data;
		}
		return [];
	},
	//删除数据
	remove: function(arg){
		var me = this;
		if (!arg) arg = {};
		$.extend(arg, {
			srfaction: 'remove'
		});
		if (IBizApp_Data) {
			arg.srfappdata = IBizApp_Data;
		}
		me.loadingTag = IBiz.beginload();
		IBiz.ajax({
			url:me.config.url,
			params:arg,
			method: 'POST',
			dataType: 'json',
			success: function(data){
				IBiz.endload(me.loadingTag );
				if (data.ret == 0) {
					me.tableselection = null;
					me.tableselections = {};
					me.loadData();
					me.fireEvent(IBizDataGrid.REMOVED,me,data);
					if (data.info && data.info != '') {
						IBiz.alert($IGM('IBIZDATAGRID.REMOVE.INFO','删除成功'));
					}
					IBiz.processResult(data);
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.REMOVE.TITLE','删除失败'),$IGM('IBIZDATAGRID.REMOVE.INFO2','删除数据失败,'+ data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.endload(me.loadingTag );
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	},
	//导出数据
	exportData: function(arg) {
		var me = this;
		var params={};
		me.fireEvent(IBizDataGrid.BEFORELOAD,me,params);
		params['query'] = params['search'];
		params['srfaction']='exportdata';
		if(arg.itemtag == 'all'){
			params['start'] = 0;
			params['limit'] = arg.exportlimit?arg.exportlimit:1000;
		}else if(arg.itemtag == 'custom'){
			var nStart = parseInt(arg.obj.find('.ibiz-id-start').val());
			var nEnd = parseInt(arg.obj.find('.ibiz-id-end').val());
			if(isNaN(nStart) || isNaN(nEnd) || (nStart<1 || nEnd <1 || nStart >nEnd)){
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.WARN','警告'),$IGM('IBIZDATAGRID.EXPORTDATA.INFO','请输入有效的起始页'),0);
				return;
			}
			params['start'] = (nStart-1)*me.pageSize;
			params['limit'] = (nEnd-nStart+1)*me.pageSize;
		}else{
			params['start'] = (me.curPage-1)*me.pageSize;
			params['limit'] = me.pageSize;
		}
		
		if(params['limit'] >65534){
			IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.WARN','警告'),$IGM('IBIZDATAGRID.EXPORTDATA.INFO3','超出导出范围'),0);
			return;
		}
		
		if (IBizApp_Data) {
			params.srfappdata = IBizApp_Data;
		}
		me.loadingTag = IBiz.beginload();
		IBiz.ajax({
			url: me.config.url,
			params: params,
			method: 'POST',
			dataType: 'json',
			success: function(data) {
				IBiz.endload(me.loadingTag );
				if (data.ret == 0) {
					if(data.downloadurl){
						var downloadurl = BASEURL+ data.downloadurl;
						IBiz.download(downloadurl);
					}
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.EXPORTDATA.TITLE','导出失败'),$IGM('IBIZDATAGRID.EXPORTDATA.INFO2','导出数据失败,' + data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.endload(me.loadingTag );
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	},
	/**
	 * 批量添加
	 */
	addBatch: function(arg) {
		var me = this;
		if (!arg) arg = {};
		$.extend(arg, {srfaction: 'addbatch'});
		
		if (IBizApp_Data) {
			arg.srfappdata = IBizApp_Data;
		}
		me.loadingTag = IBiz.beginload();
		IBiz.ajax({
			url: me.config.url,
			params: arg,
			method: 'POST',
			dataType: 'json',
			success: function(data) {
				IBiz.endload(me.loadingTag );
				if (data.ret == 0) {
					me.refresh();
					me.fireEvent(IBizDataGrid.ADDBATCHED, me, data);
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.ADDBATCH.TITLE','添加失败'),$IGM('IBIZDATAGRID.ADDBATCH.INFO','执行批量添加失败,'+ data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.endload(me.loadingTag );
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	},
	/**
	 * 提交工作流操作
	 */
	wfsubmit: function(params) {
		var me = this;
		if (!params) params = {};
		$.extend(params, {
			srfaction: 'wfsubmit'
		});
		if (IBizApp_Data) {
			params.srfappdata = IBizApp_Data;
		}
		me.loadingTag = IBiz.beginload();
		IBiz.ajax({
			url: me.config.url,
			params: params,
			method: 'POST',
			dataType: 'json',
			success: function(data) {
				IBiz.endload(me.loadingTag );
				if (data.ret == 0) {
					me.refresh();
				} else {
					IBiz.alert($IGM('IBIZDATAGRID.WFSUBMIT.TITLE','执行失败'),$IGM('IBIZDATAGRID.WFSUBMIT.INFO','执行工作流操作失败,'+ data.info,[data.info]),2);
				}
			},
			failure: function(e) {
				IBiz.endload(me.loadingTag );
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
			}
		});
	},
	doUIAction: function(params) {
		var me = this;
		var callback;
		if(params || params.callback){
			callback = params.callback;
			delete params.callback;
		}
		if (!params) params = {};
		$.extend(params,{srfaction: 'uiaction'});
		if (IBizApp_Data) {
			params.srfappdata = IBizApp_Data;
		}
		me.loadingTag = IBiz.beginload();
		IBiz.ajax({url:me.config.url,
			params:params,
			method:'POST',
			dataType:'json',
			success:function(data){
				IBiz.endload(me.loadingTag );
				if(data.ret == 0){
					if(data.reloadData){
						me.refresh();
					}
					if (data.info && data.info != '') {
						IBiz.alert($IGM('IBIZDATAGRID.DOUIACTION.INFO','操作成功'));
					}
					IBiz.processResult(data);
					
					if(callback && typeof(callback) == 'function'){
						callback({success:true,data:data});
					}
				}else{
					IBiz.alert($IGM('IBIZDATAGRID.DOUIACTION.TITLE','操作失败'),$IGM('IBIZDATAGRID.DOUIACTION.INFO2','操作失败,执行操作发生错误,'+ data.info,[data.info]),2);
					if(callback && typeof(callback) == 'function'){
						callback({success:false,data:data});
					}
				}
			},
			failure:function(e){
				IBiz.endload(me.loadingTag );
				IBiz.alert($IGM('IBIZAPP.CONFIRM.TITLE.INFO','信息'));
				if(callback && typeof(callback) == 'function'){
					callback({success:false,e:e});
				}
			}	
		});
	},
	
});

